@@ -217,6 +217,8 @@ class IntegerField(BaseField):
     def normalize_field(self, value):
         if value == '':
             value = None
+        if isinstance(value,int):
+            return value
         elif value is not None:
             value = int(i18n.get_i18n().parse_decimal(value))
         return super(IntegerField, self).normalize_field(value)
@@ -238,6 +240,8 @@ class BooleanField(BaseField):
     def normalize_field(self, value):
         if value == '':
             value = None
+        if isinstance(value,bool):
+            return value
         elif value is not None:
             value = value.upper()
             if value == 'TRUE':
@@ -271,6 +275,8 @@ class FloatField(BaseField):
             return _('Must be a number')
 
     def normalize_field(self, value):
+        if isinstance(value,(int,float)):
+            return value
         if value == '':
             value = None
         elif value is not None:
@@ -317,6 +323,8 @@ class DecimalField(BaseField):
 
 
     def normalize_field(self, value):
+        if isinstance(value,Decimal):
+            return value
         if value == '':
             value = None
         elif value is not None:
